# footer

Le pied de page propose des éléments d’information sur le site et une navigation secondaire pour l’utilisateur afin qu’il poursuive son parcours. Il est modulable selon les besoins et les exigences du site.

## Dépendances
```shell
footer
└─ core
└─ link
└─ logo
```

## Utilisation
Afin d’utiliser le composant `footer`, il est nécessaire d’ajouter les fichiers de styles et de scripts présents dans le dossier dist dans l'ordre suivant :\n
```html
<html>
  <head>
    <link href="css/core/core.min.css" rel="stylesheet">
    <link href="css/link/link.min.css" rel="stylesheet">
    <link href="css/logo/logo.min.css" rel="stylesheet">
    <link href="css/footer/footer.min.css" rel="stylesheet">
  </head>
  <body>
  </body>
</html>
```

## Documentation

Consulter [la documentation](https://www.systeme-de-design.gouv.fr/elements-d-interface/composants/pied-de-page) sur le module Pied de page